``xotl.tools`` is a collection of disparate utilities that does not conform a
framework for anything.  ``xotl.tools`` is essentially -but not exclusively-
an extension to the Python's standard library.

In ``xotl.tools`` you will probably find:

- Tools that must be implemented in the Python Standard Library, but there are
  things that escape from the Guido's scope. ;)

- Components that belong naturally to the "Common Systems Layer" \
  [#continuum]_.

.. [#continuum] http://pubs.opengroup.org/architecture/togaf9-doc/arch/chap39.html#tag_39_04_01


You'll find the documentation in `Read the Docs
<https://xoutil.readthedocs.io/>`__.
